@@ -14,11 +14,11 @@ C<Getopt::Auto::Long::Usage> - generate usage strings from Getopt::Long specs
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 =head1 SYNOPSIS
 
@@ -94,21 +94,23 @@ our @EXPORT_OK = qw( opts2bash bashgetopt );
 =head2 getoptlong2usage
 
   $usage = getoptlong2usage( Getopt_Long => \@getoptconf [,
-    descriptions => \@dsc,  # this and all other optional
+    descriptions => \@dsc,  # this & all others: optional
     cli_use => '',
     footer => '',
+    colon => ': ',
     indent => undef,
     pfx => '' ] )
 
 C<@getoptconf> is an arrayref containing all the arguments you would supply to C<GetOptions()>, including the initial hashref in which C<GetOptions()> stores results (and which is ignored). It's easiest to define C<@getoptconf> separately and reuse it for both calls. See L</"DESCRIPTION"> for an example.
 
-All other arguments are optional and shown with their defaults. I<pfx> is an arbitrary string (like C<'* '>). I<indent> sets I<pfx> to a number of spaces (don't use both). I<cli_use> goes at the top, I<footer> at the bottom, and will have a newline appended if they don't end with one.
+All other arguments are optional and shown with their defaults. I<colon> separates flags from descriptions. I<pfx> is an arbitrary string (like C<'* '>). I<indent> sets I<pfx> to a number of spaces (don't use both). I<cli_use> goes at the top, I<footer> at the bottom, and both will have a newline appended if they don't end with one.
 
 =cut
 
 sub getoptlong2usage {
   my %_O_ = @_; $_O_{ descriptions } //= [];
   $_O_{ $_ } //= '' for qw{ pfx cli_use footer };
+  $_O_{ colon } //= ': ';
   my ($conf, $pfx ) = @_O_{ qw{ Getopt_Long pfx }};
   my %dsc = @{ $_O_{ descriptions } };
 
@@ -132,13 +134,14 @@ sub getoptlong2usage {
     my @aa = split( /\|/, $a );
     # @aa = &$uniq( @aa, substr( $along, 0, 1 ) ) if length $along;  # handle auto_abbrev
     $out .= $pfx . join( ' | ', map( &$opt2dash, @aa ) );
+    my $d = ''; $d =  (length $along and $dsc{ $along }) ? "$_O_{ colon }$dsc{ $along }" : '';
     if( length $t ) {
       $t = $t2p{ $t } // "ARG:$t"; $t = "[$t]" if $isopt;
-      $out .= " $t";
+      $out .= " $t$d";
     } else {
+      $out .= $d;
       if( $isneg ) { $out .= "\n$pfx--no-" . $along if length $along; }
     }
-    $out .= ": $dsc{ $along }" if length $along and $dsc{ $along };
     $out .= "\n";
   }
   return $out . &$finalnl( $_O_{ footer } );
